@@ -2,7 +2,6 @@
 # -*- coding: utf-8 -*-
 """This module corresponds to the goddard/astro directory in idlutils.
 """
-from __future__ import print_function
 from time import time
 import numpy as np
 from astropy.units import Angstrom
@@ -28,7 +27,7 @@ def airtovac(air):
     Notes
     -----
     * Formula from `P. E. Ciddor, Applied Optics, 35, 1566 (1996)
-      <http://adsabs.harvard.edu/abs/1996ApOpt..35.1566C>`_.
+      <https://ui.adsabs.harvard.edu/abs/1996ApOpt..35.1566C/abstract>`_.
     * Values of wavelength below 2000 Å are not converted.
     """
     try:
@@ -89,7 +88,7 @@ def gcirc(ra1, dec1, ra2, dec2, units=2):
     -----
     The formula below is the one best suited to handling small angular
     separations.  See:
-    http://en.wikipedia.org/wiki/Great-circle_distance
+    https://en.wikipedia.org/wiki/Great-circle_distance
     """
     if units == 0:
         rarad1 = ra1
@@ -111,7 +110,7 @@ def gcirc(ra1, dec1, ra2, dec2, units=2):
     deldec2 = (dcrad2-dcrad1)/2.0
     delra2 = (rarad2-rarad1)/2.0
     sindis = np.sqrt(np.sin(deldec2)*np.sin(deldec2) +
-                  np.cos(dcrad1)*np.cos(dcrad2)*np.sin(delra2)*np.sin(delra2))
+                     np.cos(dcrad1)*np.cos(dcrad2)*np.sin(delra2)*np.sin(delra2))
     dis = 2.0*np.arcsin(sindis)
     if units == 0:
         return dis
@@ -175,7 +174,7 @@ def vactoair(vacuum):
     Notes
     -----
     * Formula from `P. E. Ciddor, Applied Optics, 35, 1566 (1996)
-      <http://adsabs.harvard.edu/abs/1996ApOpt..35.1566C>`_.
+      <https://ui.adsabs.harvard.edu/abs/1996ApOpt..35.1566C/abstract>`_.
     * Values of wavelength below 2000 Å are not converted.
     """
     try:
