@@ -2,6 +2,20 @@
 # -*- coding: utf-8 -*-
 """This module corresponds to the spec2d directory in idlspec2d.
 """
+from warnings import warn
+import numpy as np
+from scipy.special import erf
+from astropy import log
+from astropy.io import ascii
+from astropy.utils.data import get_pkg_data_filename
+from . import Pydlspec2dException, Pydlspec2dUserWarning
+from .. import smooth
+from ..pydlutils.bspline import iterfit
+from ..pydlutils.image import djs_maskinterp
+from ..pydlutils.math import djs_median
+from ..pydlutils.sdss import sdss_flagval
+from ..pydlutils.trace import traceset2xy, xy2traceset
+from ..goddard.astro import vactoair
 
 
 def aesthetics(flux, invvar, method='traditional'):
@@ -21,10 +35,6 @@ def aesthetics(flux, invvar, method='traditional'):
     :class:`numpy.ndarray`
         A cleaned-up spectrum.
     """
-    import numpy as np
-    from scipy.special import erf
-    from ..pydlutils.image import djs_maskinterp
-    from . import Pydlspec2dException
     badpts = invvar == 0
     if badpts.any():
         if method == 'traditional':
@@ -77,22 +87,14 @@ def combine1fiber(inloglam, objflux, newloglam, objivar=None, verbose=False,
 
     Returns
     -------
-    :func:`tuple` of :class:`numpy.ndarray`
+    :class:`tuple` of :class:`numpy.ndarray`
         The resulting flux and inverse variance.
 
     Raises
     ------
-    ValueError
+    :exc:`ValueError`
         If input dimensions don't match.
     """
-    import numpy as np
-    from astropy import log
-    from warnings import warn
-    from . import Pydlspec2dUserWarning
-    from .. import smooth
-    from ..pydlutils.bspline import iterfit
-    from ..pydlutils.math import djs_median
-    from ..pydlutils.sdss import sdss_flagval
     #
     # Log
     #
@@ -179,7 +181,7 @@ def combine1fiber(inloglam, objflux, newloglam, objivar=None, verbose=False,
         bitval = sdss_flagval('SPPIXMASK', 'NODATA')
         if 'finalmask' in kwargs:
             bitval |= (sdss_flagval('SPPIXMASK', 'NOPLUG') *
-                       (finalmask[0] & sdss_flagval('SPPIXMASK', 'NODATA')))
+                       (kwargs['finalmask'][0] & sdss_flagval('SPPIXMASK', 'NODATA')))
         andmask = andmask | bitval
         ormask = ormask | bitval
         return (newflux, newivar)
@@ -272,9 +274,8 @@ def combine1fiber(inloglam, objflux, newloglam, objivar=None, verbose=False,
                         objivar.ravel()[ss[ireplace]] = 0.0
                         log.debug('Replaced {0:d} pixels in objivar.'.format(len(ss[ireplace])))
                     if 'finalmask' in kwargs:
-                        finalmask[ss[ireplace]] = (finalmask[ss[ireplace]] |
-                                                   sdss_flagval('SPPIXMASK',
-                                                   'COMBINEREJ'))
+                        kwargs['finalmask'][ss[ireplace]] = (kwargs['finalmask'][ss[ireplace]] |
+                                                             sdss_flagval('SPPIXMASK', 'COMBINEREJ'))
             fullcombmask[ss] = bmask
         #
         # Restore objivar
@@ -312,10 +313,10 @@ def combine1fiber(inloglam, objflux, newloglam, objivar=None, verbose=False,
                 lowside = np.floor((inloglam_r[these]-newloglam[0])/binsz).astype('i4')
                 highside = lowside + 1
                 if 'finalmask' in kwargs:
-                    andmask[lowside] &= finalmask[these]
-                    andmask[highside] &= finalmask[these]
-                    ormask[lowside] |= finalmask[these]
-                    ormask[highside] |= finalmask[these]
+                    andmask[lowside] &= kwargs['finalmask'][these]
+                    andmask[highside] &= kwargs['finalmask'][these]
+                    ormask[lowside] |= kwargs['finalmask'][these]
+                    ormask[highside] |= kwargs['finalmask'][these]
                 #
                 # Combine the dispersions + skies in the dumbest way possible
                 # [sic].
@@ -325,11 +326,11 @@ def combine1fiber(inloglam, objflux, newloglam, objivar=None, verbose=False,
                     newdisp[jnbetween] += (result *
                                            np.interp(newloglam[jnbetween],
                                                      inloglam_r[these],
-                                                     indisp.ravel()[these]))
+                                                     kwargs['indisp'].ravel()[these]))
                     newsky[jnbetween] += (result *
                                           np.interp(newloglam[jnbetween],
                                                     inloglam_r[these],
-                                                    skyflux.ravel()[these]))
+                                                    kwargs['skyflux'].ravel()[these]))
         if 'indisp' in kwargs:
             newdisp /= newdispweight + (newdispweight == 0)
             newsky /= newdispweight + (newdispweight == 0)
@@ -410,19 +411,14 @@ def filter_thru(flux, waveimg=None, wset=None, mask=None,
 
     Raises
     ------
-    ValueError
+    :exc:`ValueError`
         If neither `waveimg` nor `wset` are set.
     """
-    import numpy as np
-    from astropy.io import ascii
-    from ..goddard.astro import vactoair
-    from ..pydlutils.image import djs_maskinterp
-    from ..pydlutils.trace import traceset2xy, xy2traceset
     nTrace, nx = flux.shape
     if filter_prefix != 'sdss_jun2001':
         raise ValueError("Filters other than {0} are not available!".format('sdss_jun2001'))
     ffiles = [_get_pkg_filename_compat('data/filters/{0}_{1}_atm.dat'.format(filter_prefix, f),
-                                    package='pydl.pydlutils') for f in 'ugriz']
+                                       package='pydl.pydlutils') for f in 'ugriz']
     if waveimg is None and wset is None:
         raise ValueError("Either waveimg or wset must be specified!")
     if waveimg is None:
@@ -439,7 +435,7 @@ def filter_thru(flux, waveimg=None, wset=None, mask=None,
     pixnorm, logdiff = traceset2xy(diffset)
     logdiff = np.absolute(logdiff)
     if mask is not None:
-        flux_interp = djs_maskinterp(flux, mask, iaxis=0)
+        flux_interp = djs_maskinterp(flux, mask, axis=0)
     res = np.zeros((nTrace, len(ffiles)), dtype=flux.dtype)
     for i, f in enumerate(ffiles):
         filter_data = ascii.read(f, comment='#.*', names=('lam', 'respt',
@@ -459,7 +455,6 @@ def filter_thru(flux, waveimg=None, wset=None, mask=None,
 def _get_pkg_filename_compat(filename, package):
     """Astropy 1.0.x/LTS does not accept the 'package' argument.
     """
-    from astropy.utils.data import get_pkg_data_filename
     try:
         f = get_pkg_data_filename(filename, package=package)
     except TypeError:
