@@ -2,13 +2,21 @@
 # -*- coding: utf-8 -*-
 """This module corresponds to the bspline directory in idlutils.
 """
+from warnings import warn
 import numpy as np
+from numpy.linalg.linalg import LinAlgError
+from scipy.linalg import cholesky_banded, cho_solve_banded
+from . import PydlutilsUserWarning
+from .math import djs_reject
+from .trace import fchebyshev
+from .. import uniq
+from ..goddard.math import flegendre
 
 
 class bspline(object):
-    """Bspline class.
+    """B-spline class.
 
-    Functions in the bspline library are implemented as methods on this
+    Functions in the idlutils bspline library are implemented as methods on this
     class.
 
     Parameters
@@ -16,42 +24,58 @@ class bspline(object):
     x : :class:`numpy.ndarray`
         The data.
     nord : :class:`int`, optional
-        To be documented.
+        The order of the B-spline.  Default is 4, which is cubic.
     npoly : :class:`int`, optional
-        To be documented.
+        Polynomial order to fit over 2nd variable, if supplied.  If not
+        supplied the order is 1.
     bkpt : :class:`numpy.ndarray`, optional
-        To be documented.
+        An initial breakpoint vector. If omitted, breakpoints will be
+        computed from other options.
     bkspread : :class:`float`, optional
-        To be documented.
-    verbose : :class:`bool`, optional.
-        If ``True`` print extra information.
+        Applies a scale factor to the difference between successive value of `bkpt`.
+    placed : :class:`numpy.ndarray`, optional
+        Precalculated breakpoint positions.
+    bkspace : :class:`float`, optional
+        Spacing of breakpoints in units of `x`.
+    nbkpts : :class:`int`, optional
+        Number of breakpoints to span `x` range; minimum is 2 (the endpoints).
+    everyn : :class:`int`, optional
+        Spacing of breakpoints in good pixels.
 
     Attributes
     ----------
     breakpoints
-        To be documented.
+        The processed breakpoints for the fit, based on the initialization options.
     nord
-        To be documented.
+        The order of the B-spline.  Default is 4, which is cubic.
     npoly
-        To be documented.
+        Polynomial order to fit over 2nd variable, if supplied.  If not
+        supplied the order is 1.
     mask
-        To be documented.
+        A mask for `breakpoints`.
     coeff
-        To be documented.
+        Internal attribute used by :meth:`~pydl.pydlutils.bspline.bspline.fit`.
     icoeff
-        To be documented.
+        Internal attribute used by :meth:`~pydl.pydlutils.bspline.bspline.fit`.
     xmin
-        To be documented.
+        Normalization minimum for the second variable in 2-dimensional fits.
     xmax
-        To be documented.
+        Normalization maximum for the second variable in 2-dimensional fits.
     funcname
-        To be documented.
+        For 2-dimensional fits, this is the function for the second variable.
+        The default is 'legendre'.
+
+    Notes
+    -----
+    Although this code has been tested (in the sense that it reproduces the
+    original idlutils code) and appears to work for a subset 1-dimensional cases,
+    it should not be used for 2 dimensions or more exotic 1-dimensional cases.
     """
 
     def __init__(self, x, nord=4, npoly=1, bkpt=None, bkspread=1.0,
-                 verbose=False, **kwargs):
+                 placed=None, bkspace=None, nbkpts=None, everyn=None):
         """Init creates an object whose attributes are similar to the
-        structure returned by the create_bspline function.
+        structure returned by the ``create_bsplineset()`` function.
         """
         #
         # Set the breakpoints.
@@ -59,27 +83,27 @@ class bspline(object):
         if bkpt is None:
             startx = x.min()
             rangex = x.max() - startx
-            if 'placed' in kwargs:
-                w = ((kwargs['placed'] >= startx) &
-                     (kwargs['placed'] <= startx+rangex))
+            if placed is not None:
+                w = ((placed >= startx) &
+                     (placed <= startx+rangex))
                 if w.sum() < 2:
                     bkpt = np.arange(2, dtype='f') * rangex + startx
                 else:
-                    bkpt = kwargs['placed'][w]
-            elif 'bkspace' in kwargs:
-                nbkpts = int(rangex/kwargs['bkspace']) + 1
+                    bkpt = placed[w]
+            elif bkspace is not None:
+                nbkpts = int(rangex/bkspace) + 1
                 if nbkpts < 2:
                     nbkpts = 2
                 tempbkspace = rangex/float(nbkpts-1)
                 bkpt = np.arange(nbkpts, dtype='f')*tempbkspace + startx
-            elif 'nbkpts' in kwargs:
-                nbkpts = kwargs['nbkpts']
+            elif nbkpts is not None:
                 if nbkpts < 2:
                     nbkpts = 2
                 tempbkspace = rangex/float(nbkpts-1)
                 bkpt = np.arange(nbkpts, dtype='f') * tempbkspace + startx
-            elif 'everyn' in kwargs:
-                npkpts = max(nx/kwargs['everyn'], 1)
+            elif everyn is not None:
+                nx = x.size
+                nbkpts = max(nx//everyn, 1)
                 if nbkpts == 1:
                     xspot = [0]
                 else:
@@ -90,12 +114,12 @@ class bspline(object):
         imin = bkpt.argmin()
         imax = bkpt.argmax()
         if x.min() < bkpt[imin]:
-            if verbose:
-                print('Lowest breakpoint does not cover lowest x value: changing.')
+            warn('Lowest breakpoint does not cover lowest x value: changing.',
+                 PydlutilsUserWarning)
             bkpt[imin] = x.min()
         if x.max() > bkpt[imax]:
-            if verbose:
-                print('Highest breakpoint does not cover highest x value: changing.')
+            warn('Highest breakpoint does not cover highest x value: changing.',
+                 PydlutilsUserWarning)
             bkpt[imax] = x.max()
         nshortbkpt = bkpt.size
         fullbkpt = bkpt.copy()
@@ -129,8 +153,8 @@ class bspline(object):
     def fit(self, xdata, ydata, invvar, x2=None):
         """Calculate a B-spline in the least-squares sense.
 
-        Fit is based on two variables: x which is sorted and spans a large range
-        where bkpts are required y which can be described with a low order
+        Fit is based on two variables: `xdata` which is sorted and spans a large range
+        where breakpoints are required `ydata` which can be described with a low order
         polynomial.
 
         Parameters
@@ -146,7 +170,7 @@ class bspline(object):
 
         Returns
         -------
-        :func:`tuple`
+        :class:`tuple`
             A tuple containing an integer error code, and the evaluation of the
             b-spline at the input values.  An error code of -2 is a failure,
             -1 indicates dropped breakpoints, 0 is success, and positive
@@ -179,23 +203,13 @@ class bspline(object):
                 alpha.T.flat[bo+itop*bw] += work.flat[bi]
                 beta[itop:ibottom+1] += wb
         min_influence = 1.0e-10 * invvar.sum() / nfull
-        errb = cholesky_band(alpha, mininf=min_influence)  # ,verbose=True)
+        errb = cholesky_band(alpha, mininf=min_influence)
         if isinstance(errb[0], int) and errb[0] == -1:
             a = errb[1]
         else:
             yfit, foo = self.value(xdata, x2=x2, action=a1, upper=upper, lower=lower)
             return (self.maskpoints(errb[0]), yfit)
-        errs = cholesky_solve(a, beta)
-        if isinstance(errs[0], int) and errs[0] == -1:
-            sol = errs[1]
-        else:
-            #
-            # It is not possible for this to get called, because cholesky_solve
-            # has only one return statement, & that statement guarantees that
-            # errs[0] == -1
-            #
-            yfit, foo = self.value(xdata, x2=x2, action=a1, upper=upper, lower=lower)
-            return (self.maskpoints(errs[0]), yfit)
+        sol = cholesky_solve(a, beta)
         if self.npoly > 1:
             self.icoeff[:, goodbk] = np.array(a[0, 0:nfull].reshape(self.npoly, nn), dtype=a.dtype)
             self.coeff[:, goodbk] = np.array(sol[0:nfull].reshape(self.npoly, nn), dtype=sol.dtype)
@@ -206,7 +220,7 @@ class bspline(object):
         return (0, yfit)
 
     def action(self, x, x2=None):
-        """Construct banded bspline matrix, with dimensions [ndata, bandwidth].
+        """Construct banded B-spline matrix, with dimensions [ndata, bandwidth].
 
         Parameters
         ----------
@@ -217,21 +231,18 @@ class bspline(object):
 
         Returns
         -------
-        :func:`tuple`
-            A tuple containing the b-spline action matrix; the 'lower' parameter,
+        :class:`tuple`
+            A tuple containing the B-spline action matrix; the 'lower' parameter,
             a list of pixel positions, each corresponding to the first
             occurence of position greater than breakpoint indx; and 'upper',
             Same as lower, but denotes the upper pixel positions.
         """
-        from .. import uniq
-        from ..goddard.math import flegendre
-        from .trace import fchebyshev
         nx = x.size
         nbkpt = self.mask.sum()
         if nbkpt < 2*self.nord:
             return (-2, 0, 0)
         n = nbkpt - self.nord
-        gb = self.breakpoints[self.mask]
+        # gb = self.breakpoints[self.mask]
         bw = self.npoly*self.nord
         lower = np.zeros((n - self.nord + 1,), dtype='i4')
         upper = np.zeros((n - self.nord + 1,), dtype='i4') - 1
@@ -270,10 +281,10 @@ class bspline(object):
         return (action, lower, upper)
 
     def intrv(self, x):
-        """Find the segment between breakpoints which contain each value in the array x.
+        """Find the segment between breakpoints which contain each value in the array `x`.
 
-        The minimum breakpoint is nbkptord -1, and the maximum
-        is nbkpt - nbkptord - 1.
+        The minimum breakpoint is ``nbkptord - 1``, and the maximum
+        is ``nbkpt - nbkptord - 1``.
 
         Parameters
         ----------
@@ -296,19 +307,20 @@ class bspline(object):
         return indx
 
     def bsplvn(self, x, ileft):
-        """To be documented.
+        """Calculates the value of all possibly nonzero B-splines at `x`
+        of a certain order.
 
         Parameters
         ----------
         x : :class:`numpy.ndarray`
-            To be documented.
+            Independent variable.
         ileft : :class:`int`
-            To be documented
+            Breakpoint segements that contain `x`.
 
         Returns
         -------
         :class:`numpy.ndarray`
-            To be documented.
+            B-spline values.
         """
         bkpt = self.breakpoints[self.mask]
         vnikx = np.zeros((x.size, self.nord), dtype=x.dtype)
@@ -331,7 +343,7 @@ class bspline(object):
         return vnikx
 
     def value(self, x, x2=None, action=None, lower=None, upper=None):
-        """Evaluate a bspline at specified values.
+        """Evaluate a B-spline at specified values.
 
         Parameters
         ----------
@@ -350,7 +362,7 @@ class bspline(object):
 
         Returns
         -------
-        :func:`tuple`
+        :class:`tuple`
             A tuple containing the results of the bspline evaluation and a
             mask indicating where the evaluation was good.
         """
@@ -424,9 +436,9 @@ class bspline(object):
         if np.any(hmm >= n):
             return -2
         test = np.zeros(nbkpt, dtype='bool')
-        for jj in range(-np.ceil(nord/2.0), nord/2.0):
+        for jj in range(-np.ceil(self.nord/2.0), self.nord/2.0):
             foo = np.where((hmm+jj) > 0, hmm+jj, np.zeros(hmm.shape, dtype=hmm.dtype))
-            inside = np.where((foo+nord) < n-1, foo+nord, np.zeros(hmm.shape, dtype=hmm.dtype)+n-1)
+            inside = np.where((foo+self.nord) < n-1, foo+self.nord, np.zeros(hmm.shape, dtype=hmm.dtype)+n-1)
             test[inside] = True
         if test.any():
             reality = self.mask[test]
@@ -439,87 +451,99 @@ class bspline(object):
             return -2
 
 
-def cholesky_band(l, mininf=0.0, verbose=False):
-    """Compute Cholesky decomposition of banded matrix.
+def cholesky_band(l, mininf=0.0):
+    """Compute *lower* Cholesky decomposition of a banded matrix.
+
+    This function provides informative error messages to pass back to the
+    :class:`~pydl.pydlutils.bspline.bspline` machinery; the actual
+    computation is delegated to :func:`scipy.linalg.cholesky_banded`.
 
     Parameters
     ----------
     l : :class:`numpy.ndarray`
-        A matrix on which to perform the Cholesky decomposition.
+        A matrix on which to perform the Cholesky decomposition.  The
+        matrix must be in a special, *lower* form described in
+        :func:`scipy.linalg.cholesky_banded`.  In addition, the input
+        must be padded.  If the original, square matrix has size
+        :math:`N \\times N`, and the width of the band is :math:`b`,
+        `l` must be :math:`b \\times (N + b)`.
     mininf : :class:`float`, optional
         Entries in the `l` matrix are considered negative if they are less
         than this value (default 0.0).
-    verbose : :class:`bool`, optional
-        If set to ``True``, print some debugging information.
 
     Returns
     -------
-    :func:`tuple`
+    :class:`tuple`
         If problems were detected, the first item will be the index or
         indexes where the problem was detected, and the second item will simply
         be the input matrix.  If no problems were detected, the first item
         will be -1, and the second item will be the Cholesky decomposition.
     """
-    from warnings import warn
-    from . import PydlutilsUserWarning
-    lower = l.copy()
-    bw, nn = lower.shape
+    bw, nn = l.shape
     n = nn - bw
-    negative = lower[0, 0:n] <= mininf
-    if negative.any() or not np.all(np.isfinite(lower)):
+    negative = l[0, 0:n] <= mininf
+    if negative.any() or not np.all(np.isfinite(l)):
         warn('Bad entries: ' + str(negative.nonzero()[0]), PydlutilsUserWarning)
         return (negative.nonzero()[0], l)
-    kn = bw - 1
-    spot = np.arange(kn, dtype='i4') + 1
-    bi = np.arange(kn, dtype='i4')
-    for i in range(1, kn):
-        bi = np.append(bi, np.arange(kn-i, dtype='i4') + (kn+1)*i)
-    for j in range(n):
-        lower[0, j] = np.sqrt(lower[0, j])
-        lower[spot, j] /= lower[0, j]
-        x = lower[spot, j]
-        if not np.all(np.isfinite(x)):
-            warn('NaN found in cholesky_band.', PydlutilsUserWarning)
-            return (j, l)
-        hmm = np.outer(x, x)
-        here = bi+(j+1)*bw
-        lower.T.flat[here] -= hmm.flat[bi]
-    return (-1, lower)
+    try:
+        lower = cholesky_banded(l[:, 0:n], lower=True)
+    except LinAlgError:
+        #
+        # Figure out where the error is.
+        #
+        lower = l.copy()
+        kn = bw - 1
+        spot = np.arange(kn, dtype='i4') + 1
+        for j in range(n):
+            lower[0, j] = np.sqrt(lower[0, j])
+            lower[spot, j] /= lower[0, j]
+            x = lower[spot, j]
+            if not np.all(np.isfinite(x)):
+                warn('NaN found in cholesky_band.', PydlutilsUserWarning)
+                return (j, l)
+    #
+    # Restore padding.
+    #
+    L = np.zeros(l.shape, dtype=l.dtype)
+    L[:, 0:n] = lower
+    return (-1, L)
 
 
 def cholesky_solve(a, bb):
-    """Solve the equation Ax=b where A is a Cholesky-banded matrix.
+    """Solve the equation :math:`A x = b` where `a` is a *lower*
+    Cholesky-banded matrix.
+
+    In the :class:`~pydl.pydlutils.bspline.bspline` machinery, `a` needs to
+    be padded.  This function should only used with the output of
+    :func:`~pydl.pydlutils.bspline.cholesky_band`, to ensure the proper
+    padding on `a`.  Otherwise the computation is delegated to
+    :func:`scipy.linalg.cho_solve_banded`.
 
     Parameters
     ----------
     a : :class:`numpy.ndarray`
-        :math:`A` in :math:`A x = b`.
+        *Lower* Cholesky decomposition of :math:`A` in :math:`A x = b`.
     bb : :class:`numpy.ndarray`
         :math:`b` in :math:`A x = b`.
 
     Returns
     -------
-    :func:`tuple`
-        A tuple containing the status and the result of the solution.  The
-        status is always -1.
+    :class:`numpy.ndarray`
+        The solution, padded to be the same shape as `bb`.
     """
-    b = bb.copy()
     bw = a.shape[0]
-    n = b.shape[0] - bw
-    kn = bw - 1
-    spot = np.arange(kn, dtype='i4') + 1
-    for j in range(n):
-        b[j] /= a[0, j]
-        b[j+spot] -= b[j]*a[spot, j]
-    spot = kn - np.arange(kn, dtype='i4')
-    for j in range(n-1, -1, -1):
-        b[j] = (b[j] - np.sum(a[spot, j] * b[j+spot]))/a[0, j]
-    return (-1, b)
+    n = bb.shape[0] - bw
+    x = np.zeros(bb.shape, dtype=bb.dtype)
+    x[0:n] = cho_solve_banded((a[:, 0:n], True), bb[0:n])
+    return x
 
 
 def iterfit(xdata, ydata, invvar=None, upper=5, lower=5, x2=None,
             maxiter=10, **kwargs):
-    """Iteratively fit a b-spline set to data, with rejection.
+    """Iteratively fit a B-spline set to data, with rejection.
+
+    Additional keyword parameters are passed to
+    :class:`~pydl.pydlutils.bspline.bspline`.
 
     Parameters
     ----------
@@ -527,12 +551,12 @@ def iterfit(xdata, ydata, invvar=None, upper=5, lower=5, x2=None,
         Independent variable.
     ydata : :class:`numpy.ndarray`
         Dependent variable.
-    invvar : :class:`numpy.ndarray`
+    invvar : :class:`numpy.ndarray`, optional
         Inverse variance of `ydata`.  If not set, it will be calculated based
         on the standard deviation.
-    upper : :class:`int` or :class:`float`
+    upper : :class:`int` or :class:`float`, optional
         Upper rejection threshold in units of sigma, defaults to 5 sigma.
-    lower : :class:`int` or :class:`float`
+    lower : :class:`int` or :class:`float`, optional
         Lower rejection threshold in units of sigma, defaults to 5 sigma.
     x2 : :class:`numpy.ndarray`, optional
         Orthogonal dependent variable for 2d fits.
@@ -542,10 +566,9 @@ def iterfit(xdata, ydata, invvar=None, upper=5, lower=5, x2=None,
 
     Returns
     -------
-    :func:`tuple`
+    :class:`tuple`
         A tuple containing the fitted bspline object and an output mask.
     """
-    from .math import djs_reject
     nx = xdata.size
     if ydata.size != nx:
         raise ValueError('Dimensions of xdata and ydata do not agree.')
@@ -564,7 +587,7 @@ def iterfit(xdata, ydata, invvar=None, upper=5, lower=5, x2=None,
     if x2 is not None:
         if x2.size != nx:
             raise ValueError('Dimensions of xdata and x2 do not agree.')
-    yfit = np.zeros(ydata.shape)
+    yfit = np.zeros(ydata.shape, dtype=ydata.dtype)
     if invvar.size == 1:
         outmask = True
     else:
@@ -578,13 +601,14 @@ def iterfit(xdata, ydata, invvar=None, upper=5, lower=5, x2=None,
     else:
         if not maskwork.any():
             raise ValueError('No valid data points.')
-            # return (None,None)
         if 'fullbkpt' in kwargs:
-            fullbkpt = kwargs['fullbkpt']
+            # fullbkpt = kwargs['fullbkpt']
+            raise ValueError('Input via fullbkpt is not supported!')
         else:
             sset = bspline(xdata[xsort[maskwork]], **kwargs)
             if maskwork.sum() < sset.nord:
-                print('Number of good data points fewer than nord.')
+                warn('Number of good data points fewer than nord.',
+                     PydlutilsUserWarning)
                 return (sset, outmask)
             if x2 is not None:
                 if 'xmin' in kwargs:
@@ -605,6 +629,8 @@ def iterfit(xdata, ydata, invvar=None, upper=5, lower=5, x2=None,
     ywork = ydata[xsort]
     invwork = invvar[xsort]
     if x2 is not None:
+        warn('2D bspline fits may be buggy and will be fully removed in the future.',
+             DeprecationWarning)
         x2work = x2[xsort]
     else:
         x2work = None
