@@ -9,7 +9,7 @@ from astropy.utils.data import get_pkg_data_contents
 
 def read_ds_cooling(fname, logT=None):
     """Read in the `Sutherland & Dopita (1993)
-    <http://adsabs.harvard.edu/abs/1993ApJS...88..253S>`_ cooling function.
+    <https://ui.adsabs.harvard.edu/abs/1993ApJS...88..253S/abstract>`_ cooling function.
 
     Parameters
     ----------
@@ -21,7 +21,7 @@ def read_ds_cooling(fname, logT=None):
 
     Returns
     -------
-    :func:`tuple`
+    :class:`tuple`
         A tuple containing `logT` and `loglambda`, respectively.
 
     Raises
@@ -32,14 +32,14 @@ def read_ds_cooling(fname, logT=None):
     Notes
     -----
     The data have been retrieved from
-    http://www.mso.anu.edu.au/~ralph/data/cool/ and stored in the package.
+    https://www.mso.anu.edu.au/~ralph/data/cool/ and stored in the package.
 
     Examples
     --------
     >>> from pydl.pydlutils.cooling import read_ds_cooling
     >>> logT, loglambda = read_ds_cooling('m-15.cie')
     >>> logT[0:5] # doctest: +NORMALIZE_WHITESPACE
-    array([ 4.  ,  4.05,  4.1 ,  4.15,  4.2 ])
+    array([4.  , 4.05, 4.1 , 4.15, 4.2 ])
     >>> loglambda[0:5] # doctest: +NORMALIZE_WHITESPACE
     array([-26.  , -24.66, -23.52, -22.62, -22.11])
     """
