@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 """This module corresponds to the mangle directory in idlutils.
 
-Mangle_ [1]_ is a software suite that supports the concept of polygons on
+Mangle [1]_ is a software suite that supports the concept of polygons on
 a sphere, and is used to, for example, describe the `window function`_ of the
 Sloan Digital Sky Survey.
 
@@ -20,20 +20,18 @@ bounded by *great circles*.  Mangle allows polygons to be bounded by
 *any* circle, great or not.  Use care when comparing formulas in this
 module to formulas in the mathematical literature.
 
-.. _Mangle: http://space.mit.edu/~molly/mangle/
-.. _`window function`: https://www.sdss.org/dr14/algorithms/resolve/
+.. _`window function`: https://www.sdss4.org/dr16/algorithms/resolve/
 
 References
 ----------
 
-..  [1] `Swanson, M. E. C.; Tegmark, Max; Hamilton, Andrew J. S.;
-    Hill, J. Colin, 2008 MNRAS 387, 1391
-    <http://adsabs.harvard.edu/abs/2008MNRAS.387.1391S>`_.
+.. [1] `Swanson, M. E. C.; Tegmark, Max; Hamilton, Andrew J. S.;
+   Hill, J. Colin, 2008 MNRAS 387, 1391
+   <https://ui.adsabs.harvard.edu/abs/2008MNRAS.387.1391S/abstract>`_.
 """
 import re
 import warnings
 import numpy as np
-import six
 from astropy.io import fits
 # import astropy.utils as au
 from . import PydlutilsException, PydlutilsUserWarning
@@ -212,7 +210,7 @@ class ManglePolygon(object):
         return kmin
 
     def garea(self):
-        """Compute the area of a polygon.
+        r"""Compute the area of a polygon.
 
         See [1]_ for the detailed area formula, which is summarized here:
 
@@ -231,8 +229,8 @@ class ManglePolygon(object):
         References
         ----------
 
-        ..  [1] `Hamilton, A. J. S.; Tegmark, Max, 2004 MNRAS 349, 115
-            <http://adsabs.harvard.edu/abs/2004MNRAS.349..115H>`_.
+        .. [1] `Hamilton, A. J. S.; Tegmark, Max, 2004 MNRAS 349, 115
+           <https://ui.adsabs.harvard.edu/abs/2004MNRAS.349..115H/abstract>`_.
         """
         smallest_cap = self.cmminf()
         if smallest_cap is None:
@@ -287,7 +285,7 @@ class ManglePolygon(object):
         """
         if self.gzeroar():
             return 0.0
-        warnings.warn(("The ManglePolygon.garea() method is incomplete" +
+        warnings.warn(("The ManglePolygon.garea() method is incomplete " +
                        "and is returning a dummy value."),
                       PydlutilsUserWarning)
         return 1.0
@@ -401,7 +399,7 @@ class FITS_polygon(fits.FITS_rec):
         super(FITS_polygon, self).__array_finalize__(obj)
 
     def __getitem__(self, key):
-        if isinstance(key, six.string_types):
+        if isinstance(key, (str,)):
             if key in self._pkey:
                 return super(FITS_polygon, self).__getitem__(self._pkey[key])
         return super(FITS_polygon, self).__getitem__(key)
@@ -491,7 +489,7 @@ def circle_cap(radius, points):
 
     Returns
     -------
-    :func:`tuple`
+    :class:`tuple`
         A tuple containing ``X`` and ``CM`` values for the cap.
     """
     npoints, ncol = points.shape
@@ -584,7 +582,7 @@ def is_in_polygon(polygon, points, ncaps=0):
     usencaps = p['ncaps']
     if ncaps > 0:
         usencaps = min(ncaps, p['ncaps'])
-    in_polygon = np.ones((npoints,), dtype=np.bool)
+    in_polygon = np.ones((npoints,), dtype=bool)
     for icap in range(usencaps):
         if is_cap_used(p['use_caps'], icap):
             in_polygon &= is_in_cap(p['x'][icap, :], p['cm'][icap], points)
@@ -608,7 +606,7 @@ def is_in_window(polygons, points, ncaps=0):
 
     Returns
     -------
-    :func:`tuple`
+    :class:`tuple`
         A tuple containing two :class:`~numpy.ndarray`.  First, a boolean
         vector giving the result for each point.  Second, an integer vector
         giving the index of the polygon that contains the point.
@@ -676,10 +674,12 @@ def read_mangle_polygons(filename):
         :class:`~pydl.pydlutils.mangle.ManglePolygon` objects and
         any metadata.
     """
-    with open(filename, 'rU') as ply:
-        lines = ply.read().split(ply.newlines)
+    with open(filename, 'r') as ply:
+        # lines = ply.read().split(ply.newlines)
+        lines = ply.readlines()
+    lines = [l.strip() for l in lines]
     try:
-        npoly = int(lines[0].split()[0])
+        _ = int(lines[0].strip().split()[0])
     except ValueError:
         raise PydlutilsException(("Invalid first line of {0}!  " +
                                   "Are you sure this is a Mangle " +
@@ -759,8 +759,7 @@ def set_use_caps(polygon, index_list, add=False, tol=1.0e-10,
                             if ((np.absolute(polygon.cm[i] -
                                              polygon.cm[j]) < tol) or
                                 ((polygon.cm[i] +
-                                  polygon.cm[j]) < tol and
-                                  not allow_neg_doubles)):
+                                  polygon.cm[j]) < tol and not allow_neg_doubles)):
                                 #
                                 # Don't use
                                 #
