@@ -1,11 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
+import pytest
 import numpy as np
-from os.path import dirname, join
 from astropy.io import fits
-from astropy.tests.helper import raises
+from astropy.utils.data import get_pkg_data_filename
 from ..trace import (fchebyshev, fchebyshev_split, fpoly, func_fit,
-                    TraceSet, traceset2xy, xy2traceset)
+                     TraceSet, traceset2xy, xy2traceset)
 from .. import PydlutilsException
 
 
@@ -13,16 +13,15 @@ class TestTrace(object):
     """Test the functions in pydl.pydlutils.trace.
     """
 
-    def setup(self):
+    def setup_method(self):
         # extracted from spFrame-b1-00057618.fits
-        self.sdss = fits.open(join(dirname(__file__), 't',
-                              'sdss_traceset.fits'))
+
+        self.sdss = fits.open(get_pkg_data_filename('t/sdss_traceset.fits'))
         # extracted from spFrame-r1-00180406.fits
-        self.boss = fits.open(join(dirname(__file__), 't',
-                              'boss_traceset.fits'))
+        self.boss = fits.open(get_pkg_data_filename('t/boss_traceset.fits'))
         return
 
-    def teardown(self):
+    def teardown_method(self):
         self.sdss.close()
         self.boss.close()
         return
@@ -32,7 +31,7 @@ class TestTrace(object):
         #
         # Test order
         #
-        with raises(ValueError):
+        with pytest.raises(ValueError):
             f = fchebyshev(x, 0)
         #
         # m = 1
@@ -74,9 +73,9 @@ class TestTrace(object):
         #
         # Test order
         #
-        with raises(ValueError):
+        with pytest.raises(ValueError):
             f = fchebyshev_split(x, 0)
-        with raises(ValueError):
+        with pytest.raises(ValueError):
             f = fchebyshev_split(x, 1)
         #
         # m = 2
@@ -123,8 +122,8 @@ class TestTrace(object):
         #
         # Test order
         #
-        with raises(ValueError):
-            f = fpoly(x, 0)
+        with pytest.raises(ValueError):
+            _ = fpoly(x, 0)
         #
         # m = 1
         #
@@ -167,14 +166,14 @@ class TestTrace(object):
         #
         # Bad inputs
         #
-        with raises(ValueError):
-            foo = func_fit(x, np.array([1, 2, 3]), 3)
-        with raises(ValueError):
-            foo = func_fit(x, y, 3, invvar=np.array([0, 0, 0]))
-        with raises(ValueError):
-            foo = func_fit(x, y, 3, inputfunc=np.array([1.0, 1.0, 1.0]))
-        with raises(KeyError):
-            foo = func_fit(x, y, 3, function_name='npoly')
+        with pytest.raises(ValueError):
+            _ = func_fit(x, np.array([1, 2, 3]), 3)
+        with pytest.raises(ValueError):
+            _ = func_fit(x, y, 3, invvar=np.array([0, 0, 0]))
+        with pytest.raises(ValueError):
+            _ = func_fit(x, y, 3, inputfunc=np.array([1.0, 1.0, 1.0]))
+        with pytest.raises(KeyError):
+            _ = func_fit(x, y, 3, function_name='npoly')
         #
         # No good points
         #
@@ -203,20 +202,20 @@ class TestTrace(object):
         # Fixed points
         #
         res, yfit = func_fit(x, y, 3, invvar=invvar, function_name='poly',
-                            ia=np.array([False, True, True]),
-                            inputans=np.array([1.0, 0, 0]))
+                             ia=np.array([False, True, True]),
+                             inputans=np.array([1.0, 0, 0]))
         # assert np.allclose(res,np.array([1., 1.99454782, 1.00149949]))
         assert np.allclose(res, np.array([1., 1.99340359, 1.00147743]))
         res, yfit = func_fit(x, y, 3, invvar=invvar, function_name='poly',
-                            ia=np.array([False, True, False]),
-                            inputans=np.array([1.0, 0, 1.0]))
+                             ia=np.array([False, True, False]),
+                             inputans=np.array([1.0, 0, 1.0]))
         # assert np.allclose(res,np.array([1., 1.99403239, 1.]))
         assert np.allclose(res, np.array([1., 1.99735654, 1.]))
         #
         # inputfunc
         #
         res, yfit = func_fit(x, y, 3, invvar=invvar, function_name='poly',
-                            inputfunc=np.ones(x.shape, dtype=x.dtype))
+                             inputfunc=np.ones(x.shape, dtype=x.dtype))
         # assert np.allclose(res,np.array([0.99665423, 1.9945388, 1.00172303]))
         assert np.allclose(res, np.array([0.99996197, 1.99340315, 1.00148004]))
         #
@@ -224,7 +223,7 @@ class TestTrace(object):
         #
         y = x**2 + 2*x + 0.05*np.random.randn(50)
         res, yfit = func_fit(x, y, 3, invvar=invvar, function_name='poly',
-                            ia=np.array([False, True, True]))
+                             ia=np.array([False, True, True]))
         assert np.allclose(res, np.array([0., 1.99994188, 0.99915111]))
 
     def test_traceset_sdss(self):
@@ -264,12 +263,12 @@ class TestTrace(object):
         tset = TraceSet(self.boss[1].data)
         x, y = traceset2xy(tset)
         iv = 2.0 * np.ones(x.shape, dtype=x.dtype)
-        im = np.ones(x.shape, dtype=np.bool)
+        im = np.ones(x.shape, dtype=bool)
         im[1] = False
         tset2 = TraceSet(x, y, func='chebyshev', invvar=iv, maxiter=20,
                          inmask=im)
         assert tset2.func == 'chebyshev'
 
     def test_traceset_bad(self):
-        with raises(PydlutilsException):
-            tset = TraceSet(1, 2, 3)
+        with pytest.raises(PydlutilsException):
+            _ = TraceSet(1, 2, 3)
